#!/usr/bin/env python
# -*- coding: utf-8 -*-
# -*- Python -*-

"""
 @file Cnoid_TurtleBot2_Ctrl_test.py

 @author East Japan Accounting Center Co., Ltd.

 (c)2018 The University of Aizu
 This software is released under the New BSD License.

"""
import unittest
import RTC
import OpenRTM_aist
import Cnoid_TurtleBot2_Ctrl

import os
import csv
import datetime

from mock import Mock

class TestCnoid_TurtleBot2_Ctrl(unittest.TestCase):

    def setUp(self):

        self.m = Cnoid_TurtleBot2_Ctrl.Cnoid_TurtleBot2_Ctrl(0)

        self.xx_logger = Mock()
        Cnoid_TurtleBot2_Ctrl.logger.warning = self.xx_logger.warning
        Cnoid_TurtleBot2_Ctrl.logger.error = self.xx_logger.error
        Cnoid_TurtleBot2_Ctrl.logger.info = self.xx_logger.info
        Cnoid_TurtleBot2_Ctrl.logger.debug = self.xx_logger.debug

    def test_open_read_close(self):

        rtn = False

        in_filename = ["", "psql_exp_20181017_101606_test.tsv", "psql_exp_20181017_101606_test.csv"]
        out_rtn = [False, False, True]

        for cnt in range(len(in_filename)):
            self.m._log_file_name[0] = in_filename[cnt]
            if self.m._is_open_robot_log():
                if self.m._is_csv_read():
                    self.m._read_row = 0
                    rtn = True
            # print self.m._file
            # print self.m._reader
            self.m._close_robot_log()
            # print self.m._file
            # print self.m._reader
            self.assertEqual(rtn, out_rtn[cnt])

    def test_set(self):

        out_pos_x = [0, 0.0193187]
        out_pos_y = [0, 0.0193187]
        out_theta = [0, 0.00111251]

        self.m._log_file_name[0] = "psql_exp_20181017_101606_test.csv"
        if self.m._is_open_robot_log():
            for cnt in range(len(out_pos_x)):
                if self.m._is_csv_read():
                    row = []
                    if cnt == 0:
                        header = next(self.m._reader)
                        row = next(self.m._reader)
                    else:
                        row = next(self.m._reader)
                    self.m._set(row)

                self.assertEqual(self.m._d_out_odometry.data.position.x, out_pos_x[cnt])
                self.assertEqual(self.m._d_out_odometry.data.position.y, out_pos_y[cnt])
                self.assertEqual(self.m._d_out_odometry.data.heading, out_theta[cnt])

        self.m._close_robot_log()



if __name__ == '__main__':
    unittest.main()
